@@ -48,8 +48,8 @@
 /* Compare redirection slot information with what we have */
 #define CLUSTER_REDIR_CMP(c) \
     (SLOT_SOCK(c,c->redir_slot)->port != c->redir_port || \
-    strlen(SLOT_SOCK(c,c->redir_slot)->host) != c->redir_host_len || \
-    memcmp(SLOT_SOCK(c,c->redir_slot)->host,c->redir_host,c->redir_host_len))
+    ZSTR_LEN(SLOT_SOCK(c,c->redir_slot)->host) != c->redir_host_len || \
+    memcmp(ZSTR_VAL(SLOT_SOCK(c,c->redir_slot)->host),c->redir_host,c->redir_host_len))
 
 /* Lazy connect logic */
 #define CLUSTER_LAZY_CONNECT(s) \
@@ -59,11 +59,13 @@
     }
 
 /* Clear out our "last error" */
-#define CLUSTER_CLEAR_ERROR(c) \
-    if(c->err) efree(c->err); \
-    c->err = NULL; \
-    c->err_len = 0; \
-    c->clusterdown = 0;
+#define CLUSTER_CLEAR_ERROR(c) do { \
+    if (c->err) { \
+        zend_string_release(c->err); \
+        c->err = NULL; \
+    } \
+    c->clusterdown = 0; \
+} while (0)
 
 /* Protected sending of data down the wire to a RedisSock->stream */
 #define CLUSTER_SEND_PAYLOAD(sock, buf, len) \
@@ -216,8 +218,7 @@ typedef struct redisCluster {
     short clusterdown;
 
     /* The last ERROR we encountered */
-    char *err;
-    int err_len;
+    zend_string *err;
 
     /* The slot our command is operating on, as well as it's socket */
     unsigned short cmd_slot;
@@ -367,7 +368,7 @@ PHP_REDIS_API int cluster_send_slot(redisCluster *c, short slot, char *cmd,
 
 PHP_REDIS_API redisCluster *cluster_create(double timeout, double read_timeout,
     int failover, int persistent);
-PHP_REDIS_API void cluster_free(redisCluster *c);
+PHP_REDIS_API void cluster_free(redisCluster *c, int free_ctx TSRMLS_DC);
 PHP_REDIS_API int cluster_init_seeds(redisCluster *c, HashTable *ht_seeds);
 PHP_REDIS_API int cluster_map_keyspace(redisCluster *c TSRMLS_DC);
 PHP_REDIS_API void cluster_free_node(redisClusterNode *node);
